.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`core.inputtransformer`
====================================
.. automodule:: IPython.core.inputtransformer

.. currentmodule:: IPython.core.inputtransformer

5 Classes
---------

.. autoclass:: InputTransformer
  :members:
  :show-inheritance:

.. autoclass:: StatelessInputTransformer
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: CoroutineInputTransformer
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: TokenInputTransformer
  :members:
  :show-inheritance:

  .. automethod:: __init__

.. autoclass:: assemble_python_lines
  :members:
  :show-inheritance:

  .. automethod:: __init__

11 Functions
------------

.. autofunction:: IPython.core.inputtransformer.assemble_logical_lines


.. autofunction:: IPython.core.inputtransformer.escaped_commands


.. autofunction:: IPython.core.inputtransformer.has_comment


.. autofunction:: IPython.core.inputtransformer.ends_in_comment_or_string


.. autofunction:: IPython.core.inputtransformer.help_end


.. autofunction:: IPython.core.inputtransformer.cellmagic


.. autofunction:: IPython.core.inputtransformer.classic_prompt


.. autofunction:: IPython.core.inputtransformer.ipy_prompt


.. autofunction:: IPython.core.inputtransformer.leading_indent


.. autofunction:: IPython.core.inputtransformer.assign_from_system


.. autofunction:: IPython.core.inputtransformer.assign_from_magic

